@@ -2,7 +2,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2006 by Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2006/02/12, v3.000.004, making Asnmtap v3.000.004 compatible
+# 2006/02/26, v3.000.005, making Asnmtap v3.000.005 compatible
 # ----------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -11,7 +11,7 @@ use warnings;           # Must be used in test mode only. This reduce a little p
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Plugins v3.000.004;
+use ASNMTAP::Asnmtap::Plugins v3.000.005;
 use ASNMTAP::Asnmtap::Plugins qw(:PLUGINS %STATE);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -19,25 +19,20 @@ use ASNMTAP::Asnmtap::Plugins qw(:PLUGINS %STATE);
 my $objectPlugins = ASNMTAP::Asnmtap::Plugins->new (
   _programName        => 'check_template-mail-fingerprint-xml.pl',
   _programDescription => "XML fingerprint Mail plugin template for testing the '$APPLICATION'",
-  _programVersion     => '3.000.004',
+  _programVersion     => '3.000.005',
   _programGetOptions  => ['username|u|loginname=s', 'password|passwd|p=s', 'interval|i=i', 'environment|e:s', 'timeout|t:i', 'trendline|T:i'],
   _timeout            => 30,
   _debug              => 0);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-my $username = $objectPlugins->getOptionsArgv ('username') ? $objectPlugins->getOptionsArgv ('username') : undef;
-$objectPlugins->printUsage ('Missing username') unless (defined $username);
-
-my $password = $objectPlugins->getOptionsArgv ('password') ? $objectPlugins->getOptionsArgv ('password') : undef;
-$objectPlugins->printUsage ('Missing password') unless (defined $password);
-
+my $username = $objectPlugins->getOptionsArgv ('username');
+my $password = $objectPlugins->getOptionsArgv ('password');
 my $interval = $objectPlugins->getOptionsArgv ('interval');
-$interval = 300 unless (defined $interval);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Plugins::Mail v3.000.004;
+use ASNMTAP::Asnmtap::Plugins::Mail v3.000.005;
 
 my $body = "
 
@@ -68,7 +63,7 @@ my ($returnCode, $numberOfMatches);
 # Receiving Fingerprint Mails - - - - - - - - - - - - - - - - - - - - - -
 
 ($returnCode, $numberOfMatches) = $objectMAIL->receiving_fingerprint_mails( custom => \&actionOnMailBody, receivedState => 0, outOfDate => $interval );
-$objectPlugins->pluginValue ( { alert => $numberOfMatches .' email(s)' }, $TYPE{APPEND} ) if ( defined $numberOfMatches and $numberOfMatches );
+$objectPlugins->pluginValues ( { alert => $numberOfMatches .' email(s)' }, $TYPE{APPEND} ) if ( defined $numberOfMatches and $numberOfMatches );
 
 # Sending Fingerprint Mail  - - - - - - - - - - - - - - - - - - - - - - -
 
